@@ -37,8 +37,21 @@ class TimeZoneField(models.Field):
     # NOTE: these defaults are excluded from migrations. If these are changed,
     #       existing migration files will need to be accomodated.
     default_max_length = 63
-    default_pytz_tzs = [pytz.timezone(tz) for tz in pytz.common_timezones]
-    default_zoneinfo_tzs = [ZoneInfo(tz) for tz in pytz.common_timezones]
+
+    @staticmethod
+    def get_default_pytz_tzs():
+        return [pytz.timezone(tz) for tz in pytz.common_timezones]
+
+    @staticmethod
+    def get_default_zoneinfo_tzs():
+        default_zoneinfo_tzs = []
+        for tz in pytz.common_timezones:
+            try:
+                default_zoneinfo_tzs.append(ZoneInfo(tz))
+            except ZoneInfoNotFoundError:
+                # ZoneInfo does not yet exist for this timezone
+                pass
+        return default_zoneinfo_tzs
 
     def __init__(self, *args, **kwargs):
         # allow some use of positional args up until the args we customize
@@ -50,7 +63,7 @@ class TimeZoneField(models.Field):
 
         self.use_pytz_explicit = kwargs.pop("use_pytz", None)
         self.use_pytz = self.use_pytz_explicit if self.use_pytz_explicit is not None else use_pytz_default()
-        self.default_tzs = self.default_pytz_tzs if self.use_pytz else self.default_zoneinfo_tzs
+        self.default_tzs = self.get_default_pytz_tzs() if self.use_pytz else self.get_default_zoneinfo_tzs()
 
         if "choices" in kwargs:
             values, displays = zip(*kwargs["choices"])
@@ -103,21 +116,24 @@ class TimeZoneField(models.Field):
         if self.choices_display is not None:
             kwargs["choices_display"] = self.choices_display
 
-        choices = kwargs["choices"]
-        if self.choices_display is None:
-            if choices == standard(self.default_tzs):
-                kwargs.pop("choices")
-        else:
-            values, _ = zip(*choices)
-            if sorted(values, key=str) == sorted(self.default_tzs, key=str):
-                kwargs.pop("choices")
+        # don't assume super().deconstruct() will pass us back our kwargs["choices"]
+        # https://github.com/mfogel/django-timezone-field/issues/96
+        if "choices" in kwargs:
+            if self.choices_display is None:
+                if kwargs["choices"] == standard(self.default_tzs):
+                    kwargs.pop("choices")
             else:
-                kwargs["choices"] = [(value, "") for value in values]
+                values, _ = zip(*kwargs["choices"])
+                if sorted(values, key=str) == sorted(self.default_tzs, key=str):
+                    kwargs.pop("choices")
+                else:
+                    kwargs["choices"] = [(value, "") for value in values]
 
         # django can't decontruct pytz objects, so transform choices
         # to [<str>, <str>] format for writing out to the migration
         if "choices" in kwargs:
             kwargs["choices"] = [(str(tz), n) for tz, n in kwargs["choices"]]
+
         return name, path, args, kwargs
 
     def get_internal_type(self):
